@@ -42,7 +42,7 @@ exams2qti21 <- function(file, n = 1L, nsamp = NULL, dir = ".",
 
   ## start .xml assessement creation
   ## get the possible item body functions and options  
-  itembody = list(num = num, mchoice = mchoice, schoice = schoice, cloze = cloze, string = string)
+  itembody <- list(num = num, mchoice = mchoice, schoice = schoice, cloze = cloze, string = string)
 
   for(i in c("num", "mchoice", "schoice", "cloze", "string")) {
     if(is.null(itembody[[i]])) itembody[[i]] <- list()
