@@ -1,7 +1,9 @@
 xexams <- function(file, n = 1L, nsamp = NULL,
   driver = list(sweave = NULL, read = NULL, transform = NULL, write = NULL),
-  dir = ".", edir = NULL, tdir = NULL, sdir = NULL)
+  dir = ".", edir = NULL, tdir = NULL, sdir = NULL, verbose = FALSE)
 {
+  if(verbose) cat("Exams generation initialized.\n\n")
+
   ## process driver
   if(is.null(driver$sweave)) {
     driver$sweave <- function(f) Sweave(f, quiet = TRUE)
@@ -30,6 +32,10 @@ xexams <- function(file, n = 1L, nsamp = NULL,
   dir_supp <- if(is.null(sdir)) tempfile() else sdir
   if(!file.exists(dir_supp) && !dir.create(dir_supp))
     stop(gettextf("Cannot create temporary work directory '%s'.", dir_supp))
+  if(verbose) {
+    cat(sprintf("Supplement directory: %s\n", dir_supp))
+    cat(sprintf("Temporary directory: %s\n", dir_temp))
+  }
   
   ## number of available exercises in each element of 'file'
   ## and number of selected samples per element
@@ -57,9 +63,13 @@ xexams <- function(file, n = 1L, nsamp = NULL,
   file_base <- file_path_sans_ext(file_Rnw)
   file_tex <- paste(file_base, ".tex", sep = "")
   file_path <- search_files(file_Rnw, edir, recursive = !is.null(edir))
+  file_path <- ifelse(is.na(file_path) & file.exists(file_raw), file_raw, file_path)
   file_path <- ifelse(!is.na(file_path), file_path, file.path(dir_pkg, "exercises", file_Rnw))
   if(!all(file.exists(file_path))) stop(paste("The following files cannot be found: ",
     paste(file_raw[!file.exists(file_path)], collapse = ", "), ".", sep = ""))
+  if(verbose) {
+    cat(sprintf("Exercises: %s\n", paste(file_base, collapse = ", ")))
+  }
 
   sample_id <- function() unlist(lapply(unique(file_id), function(i) {
     wi <- file_id == i
@@ -68,11 +78,17 @@ xexams <- function(file, n = 1L, nsamp = NULL,
     else
       rep(which(wi), length.out = nsamp[i])
   }))
-  
+ 
+  ## substitute (back)slashes by underscores in temporary file names
+  ## to allow handling of relative file paths (in addition to edir argument)
+  file_Rnw <- sub("^(\\./|\\.\\./)+", "", file_Rnw)
+  file_tex <- sub("^(\\./|\\.\\./)+", "", file_tex)
+  file_Rnw <- gsub("/", "_", file_Rnw, fixed = TRUE)
+  file_tex <- gsub("/", "_", file_tex, fixed = TRUE)
 
-  ## take everything to temp dir
-  file.copy(file_path, dir_temp)
-  setwd(dir_temp) 
+  ## take everything to temp dir (avoiding appending duplicated files)
+  file.copy(file_path[!duplicated(file_path)], file.path(dir_temp, file_Rnw[!duplicated(file_path)]))
+  setwd(dir_temp)
   on.exit(unlink(dir_temp), add = TRUE)
   
   ## set up list of exams (length n) with list of exercises (length m = sum(nsamp))
@@ -81,8 +97,11 @@ xexams <- function(file, n = 1L, nsamp = NULL,
   names(exm) <- paste("exam", formatC(1L:n, width = floor(log10(n)) + 1L, flag = "0"), sep = "")
   
   ## cycle through exams: call Sweave, read LaTeX, store supplementary files
+  if(verbose) cat("\nGeneration of individual exams.")
   for(i in 1L:n) {
   
+    if(verbose) cat(paste("\nExam ", format(c(i, n))[1L], ":", sep = ""))
+  
     ## sub-directory for supplementary files
     dir_supp_i <- file.path(dir_supp, names(exm)[i])
     if(!dir.create(dir_supp_i)) stop("could not create directory for supplementary files")
@@ -97,15 +116,18 @@ xexams <- function(file, n = 1L, nsamp = NULL,
 
       ## id of exercise within full list of files
       idj <- id[j]
+      if(verbose) cat(paste(" ", file_base[idj], " (", sep = ""))
 
       ## sub-directory for supplementary files
       dir_supp_ij <- file.path(dir_supp_i, names(exm[[i]])[j])
       if(!dir.create(dir_supp_ij)) stop("could not create directory for supplementary files")
 
-      ## dirver: Sweave
+      ## driver: Sweave
+      if(verbose) cat("s")
       driver$sweave(file_Rnw[idj])
 
       ## driver: read LaTeX file
+      if(verbose) cat("r")
       exm[[i]][[j]] <- driver$read(file_tex[idj])
 
       ## infer and save supplements
@@ -118,12 +140,17 @@ xexams <- function(file, n = 1L, nsamp = NULL,
       exm[[i]][[j]]$supplements <- structure(file.path(dir_supp_ij, sfile), names = sfile, dir = dir_supp_ij)
 
       ## driver: transform exercise (e.g., LaTeX -> HTML)
+      if(verbose) cat("t")
       if(!is.null(driver$transform)) exm[[i]][[j]] <- driver$transform(exm[[i]][[j]])
+      if(verbose) cat(")")
     }
 
     ## driver: write output for each exam
+    if(verbose) cat(" ... w")
     if(!is.null(driver$write)) driver$write(exm[[i]], dir = dir, info = list(id = i, n = n)) ## FIXME: do we need further information?
+    if(verbose) cat(" ... done.")
   }
+  if(verbose) cat("\n")
 
   invisible(exm)
 }
